# je_api_testka

---

## API Testka as automation framework for API testing

### Features

* HTTP Method test
* Get response data body etc...
* Action file and executor
* result compare
* xml to json and json to xml
* Soap test
* Generate HTML Report
* CLI with action file

---

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/f243c4edfc1f4aa3ac87752e3e86b399)](https://www.codacy.com/gh/JE-Chen/APITestka/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=JE-Chen/APITestka&amp;utm_campaign=Badge_Grade)

[![CircleCI](https://circleci.com/gh/JE-Chen/APITestka/tree/main.svg?style=svg&circle-token=32826b3cccdffba93891691795bbded287a0b7fe)](https://circleci.com/gh/JE-Chen/APITestka/tree/main)

[![APITestka GitHub Actions Dev](https://github.com/JE-Chen/APITestka/actions/workflows/api-testka-github-actions_dev.yml/badge.svg)](https://github.com/JE-Chen/APITestka/actions/workflows/api-testka-github-actions_dev.yml)

[![AutoControl GitHub Actions Stable](https://github.com/JE-Chen/APITestka/actions/workflows/api-testka-github-actions_stable.yml/badge.svg)](https://github.com/JE-Chen/APITestka/actions/workflows/api-testka-github-actions_stable.yml)

### Documentation

[![Documentation Status](https://readthedocs.org/projects/apitestka/badge/?version=latest)](https://apitestka.readthedocs.io/en/latest/?badge=latest)

https://apitestka.readthedocs.io/en/latest/

---

## install

```
pip install je_api_testka
```

## Requires

```
python 3.7 or later
```